/* Directly depends on One */
void OneFunc();

int main(void)
{
  OneFunc();
  return 0;
}
